# -*- coding: utf-8 -*-
"""

Example of using numpy and matplotlib together

@author: bgregor
"""

import numpy as np
import matplotlib.pyplot as plt


def read_file(filename):
    ''' Read the data file and return a numpy array '''
    # Method #1: read the data into a Python list
    # then convert it to a numpy array with np.array
    #
    #  f = open(filename,'r')
    #  data = np.array(f.readlines())
    #
    # Method #2: use a numpy function to do the reading.
    #  This avoids the overhead of creating the Python list and
    #  then converting it to numpy.
    data = np.loadtxt(filename,delimiter=',')
    return data




# Step 1:  read the file
waves = read_file('waves.txt')

# Step 2: let's plot it!
# The time_step is the number of times per second the signal was sampled
time_step = 1 / 1000.0
time_pts = np.arange(waves.shape[0]) * time_step
plt.plot(time_pts,waves)
plt.xlabel('seconds')
plt.ylabel('amplitude')
plt.show()

# This is some sine waves mixed with noise.  Let's
# identity the sine wave frequencies.

# Step 3: Compute the power spectrum
# The power spectrum shows the amount of power vs.
# frequency in the signal. The original sine waves will 
# appear as peaks in the plot.

# Use numpy to perform a Fast Fourier Transform on the signal
# and compute its power spectrum.  This is the square of the 
# absolute value of the FFT of the signal.
ps = np.abs(np.fft.rfft(waves))**2

# Use the built-in numpy function to identify the frequencies
# in the power spectrum

freqs = np.fft.fftfreq(waves.size, time_step)

# Freqs is sorted inconveniently.  Get an index to freqs that will
# output it in a sorted order.  However...we only want the frequencies
# >0 as the power spectrum is mirrored about the y-axis.  Use an indexing
# trick here:
idx = np.argsort(freqs[freqs > 0])
plt.plot(freqs[idx ],ps[idx ])
plt.show()
# That's hard to see...let's re-plot with some control over the
# x-axis
plt.plot(freqs[idx ],ps[idx ])
plt.xlim(0,50)
plt.show()
# the peaks are very visible now!



